package logwire.core.bo.object;

import logwire.core.bo.annotation.Column;
import logwire.core.bo.annotation.Composite;
import logwire.core.bo.field.BizExpando;
import logwire.core.bo.field.BizOne;

import java.time.OffsetDateTime;
import java.util.Map;

/**
 * BO 生成的Model,audit=false version=true domain=true, 指定ID为主键，非AUTO；audit由BO控制
 * BO 子表字段(多对多、数组、大文本)生成的Model，audit/version/domain都为false
 */
public abstract class BizObject extends ModelObject {

    String txCode; //事务类型 insert/update/delete

    Map updatedFields; //当事务类型为update时，记录修改过的字段

    @Column(label="主键")
    Long id;// BO 的ID全部为雪花ID

    @Column(label="版本号")
    int version;

    @Column(label = "BO名称")
    String boName = this.getClass().getSimpleName();

    @Column(label="创建用户")
    BizOne<User> insert_user;

    @Column(label="创建时间")
    OffsetDateTime insert_date;

    @Column(label="最后修改用户")
    BizOne<User> update_user;

    @Column(label="最后修改时间")
    OffsetDateTime update_date;

    @Composite(label = "项目扩展字段", prefix = "exp_")
    BizExpando exps;

    @Column(label="域")
    String domain_name;


    @Override
    public Object getId() {
        return id;
    }


    public String getTxCode() {
        return txCode;
    }

    public void setTxCode(String txCode) {
        this.txCode = txCode;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public int getVersion() {
        return version;
    }

    public void setVersion(int version) {
        this.version = version;
    }

    public String getBoName() {
        return boName;
    }

    public void setBoName(String boName) {
        this.boName = boName;
    }

    public Map<String, Object> getUpdatedFields() {
        return updatedFields;
    }
    public BizExpando getExps() {
        return exps;
    }

    public void setExps(BizExpando exps) {
        this.exps = exps;
    }

    public BizOne<User> getInsert_user() {
        return insert_user;
    }

    public void setInsert_user(BizOne<User> insert_user) {
        this.insert_user = insert_user;
    }

    public OffsetDateTime getInsert_date() {
        return insert_date;
    }

    public void setInsert_date(OffsetDateTime insert_date) {
        this.insert_date = insert_date;
    }

    public BizOne<User> getUpdate_user() {
        return update_user;
    }

    public void setUpdate_user(BizOne<User> update_user) {
        this.update_user = update_user;
    }

    public OffsetDateTime getUpdate_date() {
        return update_date;
    }

    public void setUpdate_date(OffsetDateTime update_date) {
        this.update_date = update_date;
    }

    public String getDomain_name() {
        return domain_name;
    }

    public void setDomain_name(String domain_name) {
        this.domain_name = domain_name;
    }
}
